@@ -25,7 +25,7 @@ from qm_spider.threading_py import *
 #         end = time.time()
 #         print("%s子进程结束，进程ID：%d。耗时0.2%f" % (self.appname, os.getpid(), end - start))
 
-def top_keyword_multiprocessing(appid_list, keyword_hot_start, start_time, end_time, file_path):
+def top_keyword_multiprocessing(appid_list, keyword_hot_start, start_time, end_time, file_path='./'):
     # 创建多个进程，表示可以同时执行的进程数量。默认大小是CPU的核心数
     p = Pool(len(appid_list))
     for appid in appid_list:
